@@ -110,6 +110,20 @@ class DelayedSqlExecutor(object):
         self.records_processed = 0
         self.connection = cursor.connection
 
+    def get_fields(self, tablename):
+        default_sql = 'select * from %s LIMIT 1' % tablename
+        sql = {
+               'sqlite': default_sql,
+               'mysql': default_sql,
+               'postgres': default_sql
+               }
+        self.cursor.execute(sql.get(self.get_dbname(), 'select * from %s' % tablename))
+        self.clean_house()
+        fields = []
+        for idx, field_attrs in enumerate(self.cursor.description):
+            fields.append(field_attrs[0])
+        return fields
+
     def add_object(self, tablename, pk=PK_ID, keyname=None):
         """
         Adds a tablename to the internal list of tables, find its columns, storing
@@ -117,12 +131,8 @@ class DelayedSqlExecutor(object):
         """
         if not keyname:
             keyname = tablename
-        self.cursor.execute('select * from %s' % tablename)
-        self.clean_house()
-        fields = []
-        for idx, field_attrs in enumerate(self.cursor.description):
-            fields.append(field_attrs[0])
 
+        fields = self.get_fields(tablename)
         if self.debug:
             logging.debug("AddObject: %s. Fields = %s" % (tablename, fields))
 
@@ -222,11 +232,10 @@ class DelayedSqlExecutor(object):
                 if fieldvalues:
                     self.sql_calls += 1
                     try:
-                        self.cursor.executemany('\n'.join(sql), fieldvalues)
-                        self.clean_house()
+                        self._executemany('\n'.join(sql), fieldvalues)
                     except Exception, e:
                         raise UpdateManyException(e, tablename, sql, fieldvalues)
-
+                        
                 for items in params_for_execute:
                     sql = ['update %s set' % tablename]
                     m = []
@@ -247,11 +256,10 @@ class DelayedSqlExecutor(object):
 
                     self.sql_calls += 1
                     try:
-                        self.cursor.execute('\n'.join(sql), fieldvalues)
-                        self.clean_house()
+                        self._executeone('\n'.join(sql), fieldvalues)
                     except Exception, e:
                         raise UpdateOneException(e, tablename, sql, fieldvalues)
-
+                        
             if v.insert_items:
                 sql = 'insert into %s (%s) values (%s)' % \
                     (v.tablename, ', '.join([self.quote(f) for f in v.fields if f != v.pk]), \
@@ -275,12 +283,38 @@ class DelayedSqlExecutor(object):
 
                 self.sql_calls += 1
                 try:
-                    self.cursor.executemany(sql, fieldvalues)
-                    self.clean_house()
+                    self._executemany(sql, fieldvalues)
                 except Exception, e:
-                    raise InsertManyException(e, tablename, sql, fieldvalues)
-            v.reset()
+                    raise InsertManyException(e, tablename, sql, fieldvalues)            
 
+            v.reset()
+        
+    def _executeone(self, sql, fieldvalues):
+        """"
+        Executes a single sql statement and reconnects by recreating the cursor
+        if the connection to the database is lost.
+        """
+        try:
+            self.cursor.execute(sql, fieldvalues)
+        except:
+            self.cursor = self.connection.cursor()
+            self.cursor.execute(sql, fieldvalues)
+        finally:
+            self.clean_house()
+        
+    def _executemany(self, sql, fieldvalues):
+        """"
+        Executes many sql statements and reconnects by recreating the cursor
+        if the connection to the database is lost.
+        """
+        try:
+            self.cursor.executemany(sql, fieldvalues)
+        except:
+            self.cursor = self.connection.cursor()
+            self.cursor.executemany(sql, fieldvalues)
+        finally:
+            self.clean_house()
+        
     def clean_house(self):
         """
         This method removes the last query from the list of queries stored in the django connection
